Regolith-Subfunctions
=====================

A Python package for easier reuseability of the Subfunctions Regolith filter for Minecraft Bedrock Edition 

Documentation
-------------

This module is just a component used by the subfunctions Regolith filter and
its intended to be used by that filter only. You can find the documentation
of the filter on the page of the filter: https://github.com/Nusiq/regolith-filters/tree/master/subfunctions

Installation
-------------

.. code-block:: bash

   pip install better-json-tools

